@@ -3,6 +3,7 @@ import contextlib
 import json
 from abc import ABC, abstractmethod
 from typing import Optional
+from pydantic import BaseSettings
 from shared_dependencies.sentry import safe_capture_exception
 from shared_dependencies.http_client import CustomAsyncClient
 
@@ -73,6 +74,23 @@ def tempenv(**update):
             env[k] = v
 
 
+@contextlib.contextmanager
+def temp_settings(settings: BaseSettings, **update):
+    """
+    Temporarily updates a settings class instance
+    :param settings: Settings class.
+    :param update: Dictionary of settings values to add/update.
+    """
+    previous_settings = settings.dict()
+    update = {k.lower(): v for k, v in update.items()}
+    for k, v in update.items():
+        settings.__setattr__(k, v)
+    yield
+
+    for k, v in update.items():
+        settings.__setattr__(k, previous_settings[k])
+
+
 class CachingEngine(ABC):
     @abstractmethod
     def set(self, key: str, val: str):
